@@ -9,8 +9,8 @@ class GitCPP:
     def is_repository(self):
         return os.path.exists(os.path.join(self.git_path, ".git"))
 
-    def cmd(self, cmd):
-        if self.is_repository():
+    def cmd(self, cmd, force=False):
+        if self.is_repository() or force:
             os.chdir(self.git_path)
             subprocess.call(("git %s"%cmd).encode(sys.stdout.encoding), shell=True)
 
@@ -24,6 +24,9 @@ class GitCPP:
         self.cmd("add -A")
         self.cmd("commit -m \"%s\""%commit_message)
 
+    def init(self):
+        self.cmd("init", force=True)
+
     def push(self):
         self.cmd("push origin master")
 
